#!/usr/bin/perl
#
# $Id: mysql_rotate.pl,v 1.3 2008-01-02 13:31:38 anton Exp $
# 
# This script removes old unnecessary data from netams tables.
# 
# Data removed older then 2 month.

use DBI;
use Time::Local;

($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
$mon-=2;
if($mon<0) {
	$mon+=12;
	$year--;
}
$time = timelocal(0,0,0,1,$mon,$year);

#($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime($time);
#print "$mday $mon $year\n";

# Data required to do a script login, change this
# login to netams
$sql_type="mysql";
$sql_dbname="netams";
$sql_host="localhost";
$sql_port=20001;
$sql_login="admin";
$sql_password="123";

$dbh = DBI->connect("DBI:$sql_type:database=$sql_dbname;host=$sql_host", $sql_login, $sql_password);
	if ($dbh eq "") {
                $p1.="Unable to connect to SQL radius database!\n"; }
        else {
                $p1.="Connected to database $sql_dbname \n";
        }

#clear raw 
	$dbh->do("DELETE FROM raw WHERE t_from<$time");
#clear events
	$dbh->do("DELETE FROM events WHERE time<$time");
#clear bstat
	$dbh->do("DELETE FROM bstat WHERE t_from<$time");
 
